#!/usr/bin/env python
# -*- coding: iso-8859-1 -*-

"An OpenID login example with some local user pages."

from WebStack.Resources.OpenIDLogin import OpenIDLoginResource, Authenticator
from WebStack.Resources.ResourceMap import MapResource
from WebStack.Resources.Static import StringResource
from WebStack.Generic import ContentType

def get_site_map(app_url, deployment_url):

    """
    Return a resource for the site having the given 'app_url' and
    'deployment_url'. The 'app_url' should be the "bare" reference using a
    protocol, host and port, not including any path information.
    """

    login = OpenIDLoginResource(
        app_url=app_url,
        authenticator=Authenticator(
            credentials=(
                # Local identifier,           username,  password
                ((deployment_url + "/badger", "badger"), "abc"),
                ((deployment_url + "/vole",   "vole"),   "xyz"),
                ((deployment_url + u"/",   u""),   u""),
                )
            )
        )

    return MapResource({
        "" : login,
        "login" : login,

        # Some local OpenID pages.

        "badger" :
            StringResource("""
                <html>
                  <head>
                    <link rel="openid2.provider openid.server" href="%s/login" />
                    <link rel="openid2.local_id openid.delegate" href="%s/badger" />
                    <title>Badger's Home Page</title>
                  </head>
                  <body>
                    <p>Home page for the OpenID authenticated user, <code>badger</code>.</p>
                  </body>
                </html>
            """ % (deployment_url, deployment_url), ContentType("text/html")),
        u"" :
            StringResource(u"""
                <html>
                  <head>
                    <link rel="openid2.provider openid.server" href="%s/login" />
                    <link rel="openid2.local_id openid.delegate" href="%s/" />
                    <title>Home Page for </title>
                  </head>
                  <body>
                    <p>Home page for the OpenID authenticated user, <code></code>.</p>
                  </body>
                </html>
            """ % (deployment_url, deployment_url), ContentType("text/html", "iso-8859-1")),
        "vole" :
            StringResource("""
                <html>
                  <head>
                    <link rel="openid2.provider openid.server" href="%s/login" />
                    <link rel="openid2.local_id openid.delegate" href="%s/vole" />
                    <title>Vole's Home Page</title>
                  </head>
                  <body>
                    <p>Home page for the OpenID authenticated user, <code>vole</code>.</p>
                  </body>
                </html>
            """ % (deployment_url, deployment_url), ContentType("text/html"))
        })

# vim: tabstop=4 expandtab shiftwidth=4
